{
  "type": "record",
  "name": "DataHubRetentionKey",
  "namespace": "com.linkedin.pegasus2avro.metadata.key",
  "doc": "Key for a DataHub Retention",
  "fields": [
    {
      "name": "entityName",
      "type": "string",
      "doc": "Entity name to apply retention to. * (or empty) for applying defaults."
    },
    {
      "name": "aspectName",
      "type": "string",
      "doc": "Aspect name to apply retention to. * (or empty) for applying defaults."
    }
  ],
  "Aspect": {
    "name": "dataHubRetentionKey"
  }
}