{
  "type": "record",
  "name": "CorpGroupInfo",
  "namespace": "com.linkedin.pegasus2avro.identity",
  "doc": "Information about a Corp Group ingested from a third party source",
  "fields": [
    {
      "name": "displayName",
      "type": [
        "null",
        "string"
      ],
      "doc": "The name of the group.",
      "default": null,
      "Searchable": {
        "fieldType": "TEXT_PARTIAL"
      }
    },
    {
      "name": "email",
      "type": [
        "null",
        "string"
      ],
      "doc": "email of this group",
      "default": null
    },
    {
      "name": "admins",
      "type": {
        "type": "array",
        "items": "string"
      },
      "doc": "owners of this group\nDeprecated! Replaced by Ownership aspect.",
      "Relationship": {
        "/*": {
          "entityTypes": [
            "corpuser"
          ],
          "name": "OwnedBy"
        }
      },
      "deprecated": true
    },
    {
      "name": "members",
      "type": {
        "type": "array",
        "items": "string"
      },
      "doc": "List of ldap urn in this group.\nDeprecated! Replaced by GroupMembership aspect.",
      "Relationship": {
        "/*": {
          "entityTypes": [
            "corpuser"
          ],
          "name": "IsPartOf"
        }
      },
      "deprecated": true
    },
    {
      "name": "groups",
      "type": {
        "type": "array",
        "items": "string"
      },
      "doc": "List of groups in this group.\nDeprecated! This field is unused.",
      "Relationship": {
        "/*": {
          "entityTypes": [
            "corpGroup"
          ],
          "name": "IsPartOf"
        }
      },
      "deprecated": true
    },
    {
      "name": "description",
      "type": [
        "null",
        "string"
      ],
      "doc": "A description of the group.",
      "default": null,
      "Searchable": {
        "fieldType": "TEXT_PARTIAL"
      }
    }
  ],
  "Aspect": {
    "EntityUrns": [
      "com.linkedin.pegasus2avro.common.CorpGroupUrn"
    ],
    "name": "corpGroupInfo"
  }
}