{
  "type": "record",
  "name": "GlobalTags",
  "namespace": "com.linkedin.pegasus2avro.common",
  "doc": "Tag aspect used for applying tags to an entity",
  "fields": [
    {
      "name": "tags",
      "type": {
        "type": "array",
        "items": {
          "type": "record",
          "name": "TagAssociation",
          "doc": "Properties of an applied tag. For now, just an Urn. In the future we can extend this with other properties, e.g.\npropagation parameters.",
          "fields": [
            {
              "name": "tag",
              "type": "string",
              "doc": "Urn of the applied tag",
              "Relationship": {
                "entityTypes": [
                  "tag"
                ],
                "name": "TaggedWith"
              },
              "Searchable": {
                "addToFilters": true,
                "fieldName": "tags",
                "fieldType": "URN",
                "filterNameOverride": "Tag",
                "hasValuesFieldName": "hasTags"
              },
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.TagUrn"
              }
            },
            {
              "name": "context",
              "type": [
                "null",
                "string"
              ],
              "doc": "Additional context about the association",
              "default": null
            }
          ]
        }
      },
      "doc": "Tags associated with a given entity"
    }
  ],
  "Aspect": {
    "name": "globalTags"
  }
}